### Chat with multiple LLMs (from markdown)
Here you can try multiple LLMs without a system prompt. 
i.e. the messages you can see on screen are the ones sent to the LLMs 
(with a small variation where only the first 512 chars of the LLM's response is sent to the LLM)